# A brief description of the package:

_The package consists of **two parts:**_

## First: Gaussian Probability Distribution Function:

**Gaussian Class** is dealing with probability for periods

All it need as attributes **the Mean** and **Standard Deviation _respictively_** and it will show all the information you want to know about the probability distribution function for more information you can use _**help**_ function for Gaussian class

## Second: Binomial Probability:

All it needs **the probability** and **the number of succeed trials** and it will also show all the other information like _the mean and Standard Deviation and etc.._

That was a quick and brief description for the package content, more information is provided in the dosstring of the classes.